@@ -25,7 +25,7 @@ use Moo;
 use experimental 'signatures';
 use experimental 'refaliasing';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Exporter::Shiny qw( join_n overlay_n );
 
@@ -484,7 +484,6 @@ sub _reset_layer ( $tree ) {
 
 
 
-
 
 
 sub overlay_n {
@@ -505,7 +504,7 @@ sub overlay_n {
     $opt->{snap_to}   //= 'underlay';
     $opt->{snap_dist} //= Math::BigFloat->bzero;
 
-    my $tr = Tree::Range::RB->new;
+    my $tr = Tree::Range::RB->new( { cmp => sub { $_[0] <=> $_[1] } } );
 
     my $gi = 0;
     for my $grid ( $grids->@* ) {
@@ -732,26 +731,6 @@ sub _merge_bins ( $tr, $snap_dist, $snap_to, $scan_direction ) {
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 
 
@@ -1025,7 +1004,7 @@ CXC::Number::Grid - A class representing a one dimensional numeric grid
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -1223,25 +1202,24 @@ Returns an object which returns piddles for the following methods
 
 Overlay each successive grid on the overlay of the previous sequence of grids.
 The process essentially excises the range in the underlying grid covered by the
-overlying grid and inserts the overlying grid in that place.  For example,
+overlying grid and inserts the overlying grid in that place.  For example, if
 
-C<$grid1> is the underlying grid,
+  $overlay = overlay_n( $grid1, $grid2 );
 
-     +-------------------------------------------------+
-     |    |    |    |    |    |    |    |    |    |    |
-     +-------------------------------------------------+
+with
 
-and C<$grid2> is the grid which will be overlayed:
-
-            +--------------------------------+
-            |          |         |           |
-            +--------------------------------+
-
-The result of C<overlay_n( $grid1, $grid2 )> is:
-
-     +-------------------------------------------------+
-     |    | |          |         |           |    |    |
-     +-------------------------------------------------+
+ $grid1:
+ :     +-------------------------------------------------+
+ :     |    |    |    |    |    |    |    |    |    |    |
+ :     +-------------------------------------------------+
+ $grid2:
+ :            +--------------------------------+
+ :            |          |         |           |
+ :            +--------------------------------+
+ $overlay:
+ :     +-------------------------------------------------+
+ :     |    | |          |         |           |    |    |
+ :     +-------------------------------------------------+
 
 The C<%options> hash is optional; the following options are available:
 
@@ -1322,98 +1300,80 @@ Available directives are:
 
 Translate the left grid until its maximum edge coincides with the right grid's minimum edge.
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-    +-----------------------+-----------------------+
-    |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
-    +-----------------------+-----------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :    +-----------------------+-----------------------+
+ :    |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
+ :    +-----------------------+-----------------------+
 
 =item C<shift-left>
 
 Translate the right grid until its minimum edge coincides with the let grid's maximum edge.
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-----------------------+-----------------------+
-  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
-  +-----------------------+-----------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-----------------------+-----------------------+
+ :  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
+ :  +-----------------------+-----------------------+
 
 =item C<snap-right>
 
 Set the left grid's maximum edge to the right grid's minimum edge.
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-------------------------------------------------+
-  |  |  |  |  |  |  |  |    |  |  |  |  |  |  |  |  |
-  +-------------------------------------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-------------------------------------------------+
+ :  |  |  |  |  |  |  |  |    |  |  |  |  |  |  |  |  |
+ :  +-------------------------------------------------+
 
 =item C<snap-left>
 
 Set the right grid's minimum edge to the left grid's maximum edge.
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-------------------------------------------------+
-  |  |  |  |  |  |  |  |  |    |  |  |  |  |  |  |  |
-  +-------------------------------------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-------------------------------------------------+
+ :  |  |  |  |  |  |  |  |  |    |  |  |  |  |  |  |  |
+ :  +-------------------------------------------------+
 
 =item C<snap-both>
 
 Set both the right grid's minimum edge and the left grid's maximum edge
 to the average of the two.
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-------------------------------------------------+
-  |  |  |  |  |  |  |  |   |   |  |  |  |  |  |  |  |
-  +-------------------------------------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-------------------------------------------------+
+ :  |  |  |  |  |  |  |  |   |   |  |  |  |  |  |  |  |
+ :  +-------------------------------------------------+
 
 =item C<include>
 
 Add a new bin
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-------------------------------------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-------------------------------------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-------------------------------------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-------------------------------------------------+
 
 =back
 
@@ -1421,17 +1381,14 @@ After:
 
 Add a new bin, and mark it as being excluded
 
-Before:
-
-  +-----------------------+ +-----------------------+
-  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
-  +-----------------------+ +-----------------------+
-
-After:
-
-  +-------------------------------------------------+
-  |  |  |  |  |  |  |  |  |X|  |  |  |  |  |  |  |  |
-  +-------------------------------------------------+
+ Before:
+ :  +-----------------------+ +-----------------------+
+ :  |  |  |  |  |  |  |  |  | |  |  |  |  |  |  |  |  |
+ :  +-----------------------+ +-----------------------+
+ After:
+ :  +-------------------------------------------------+
+ :  |  |  |  |  |  |  |  |  |X|  |  |  |  |  |  |  |  |
+ :  +-------------------------------------------------+
 
 =back
 
